%   Filename:  empty_module_default.m
%
%	description : parameter file for ADVANCE empty module
%	author      : J.Eelkema
%
%  ============================================================
%   ADVANCE, TNO, The Netherlands
%   advance@wt.tno.nl
%  ============================================================


dat.comment = 'Simple control strategy for parallel hybrid vehicle';
dat.filename = 'para_ecu_example1.m';
dat.version = '1';
dat.lastModified = '28.03.2013';
dat.modifiedBy = 'Jonas Fredriksson';

dat.idleSpeed.comment = 'idle speed for engine';
dat.idleSpeed.unit = 'rad/s';
dat.idleSpeed.value = 600*2*pi/60;

dat.crankingtime.comment = 'starter motor cranking time';
dat.crankingtime.unit = 's';
dat.crankingtime.value = 1;

dat.maxEngineTorque.comment = 'maximum engine torque';
dat.maxEngineTorque.unit = 'Nm';
dat.maxEngineTorque.value = 630;

dat.maxEMTorque.comment = 'maximum electric machine torque torque';
dat.maxEMTorque.unit = 'Nm';
dat.maxEMTorque.value = 120;

dat.maxEMBrakeTorque.comment = 'maximum electric machine brake torque';
dat.maxEMBrakeTorque.unit = 'Nm';
dat.maxEMBrakeTorque.value = 120;

dat.maxMechBrakeTorque.comment = 'maximum mechanical brake torque';
dat.maxMechBrakeTorque.unit = 'Nm';
dat.maxMechBrakeTorque.value = 40000;

dat.maxTorque.comment = 'maximum torque from energy converters, added';
dat.maxTorque.unit = 'Nm';
dat.maxTorque.value = dat.maxEngineTorque.value + dat.maxEMTorque.value;

dat.pedalmap.comment = 'torque request from driver = f(pedal position, engine speed)';
dat.pedalmap.pedalComment = 'pedal position [0-1]';
dat.pedalmap.pedalUnit = '-';
dat.pedalmap.pedal = [0 1];
dat.pedalmap.speedComment = 'engine speed';
dat.pedalmap.speedUnit = 'rad/s';
dat.pedalmap.speed = [0 400];
dat.pedalmap.mapComment = 'requested torque';
dat.pedalmap.mapUnit = 'Nm';
dat.pedalmap.map = [0 0;dat.maxTorque.value dat.maxTorque.value];

dat.finalgear.comment = 'final gear ratio';
dat.finalgear.unit = '-';
dat.finalgear.value = 4.9;

dat.mechgear.comment = 'gearing between combustion engine and electric machine';
dat.mechgear.unit = '-';
dat.mechgear.value = 2.88;

dat.wheelradius.comment = 'wheel radius';
dat.wheelradius.unit = 'm';
dat.wheelradius.value = 0.4;

dat.gearnr.comment = 'number of gears';
dat.gearnr.unit = '-';
dat.gearnr.value = 6;

dat.gearname.comment = 'Name of gears';
dat.gearname.unit = '-';
dat.gearname.value = [0 1 2 3 4 5 6 7 8 9 10 11 12];

dat.gearratio.comment = 'Gear ratio';
dat.gearratio.unit = '-';
dat.gearratio.value = [0 6.7 4 2.3 1.4 1 0.75 0.5 0.5 0.5 0.5 0.5 0.5];

dat.socstrategy.comment = 'Energy strategy';
dat.socstrategy.socrefComment = 'Reference state of charge';
dat.socstrategy.socrefUnit = '-';
dat.socstrategy.socref = 0.5;
dat.socstrategy.KsocComment = 'Proportional controller, gain';
dat.socstrategy.KsocUnit = '-';
dat.socstrategy.Ksoc = 20;
dat.socstrategy.SwitchSpeedComment = 'Switch speed';
dat.socstrategy.SwitchSpeed = 'm/s';
dat.socstrategy.SwitchSpeed = 3;

%____Connection information__________________________
%The con_info structure describes the signals and the order of the signals that are needed for on the con_i port.
%The 'desr' field gives a description of the signal and the 'unit' field contains the required unit.
%This information is used for the GUI of the ADVANCE busselector.
con_info(1).descr = 'Driver Input';
con_info(1).unit = '[-]';
con_info(2).descr = 'Engine Input';
con_info(2).unit = '[-]';
con_info(3).descr = 'Battery Input';
con_info(3).unit = '[-]';
con_info(4).descr = 'Electric machine Input';
con_info(4).unit = '[-]';
con_info(5).descr = 'Transmission Input';
con_info(5).unit = '[-]';
con_info(6).descr = 'Chassis Input';
con_info(6).unit = '[-]';


%%%%%%%%%%%
%revision history
% 
